==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/entitysafetydefault_001/EntitySafetyDefault.java <==

package net.datastream.schemas.mp_entities.entitysafetydefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELETEPENDING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPLYTOCHILDREN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RBSIGNATURETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EntitySafetyDefault_001}SafetyReviewDetail" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="has_department_security" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "deletepending",
    "applytochildren",
    "locationid",
    "categorycode",
    "rstatus",
    "rbsignaturetype",
    "safetyReviewDetail"
})
@XmlRootElement(name = "EntitySafetyDefault")
public class EntitySafetyDefault {

    @XmlElement(name = "DELETEPENDING", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String deletepending;
    @XmlElement(name = "APPLYTOCHILDREN", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String applytochildren;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "CATEGORYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String categorycode;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlElement(name = "RBSIGNATURETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String rbsignaturetype;
    @XmlElement(name = "SafetyReviewDetail")
    protected SafetyReviewDetail safetyReviewDetail;
    @XmlAttribute(name = "has_department_security")
    protected String has_Department_Security;

    /**
     * Obtient la valeur de la propriété deletepending.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDELETEPENDING() {
        return deletepending;
    }

    /**
     * Définit la valeur de la propriété deletepending.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDELETEPENDING(String value) {
        this.deletepending = value;
    }

    /**
     * Obtient la valeur de la propriété applytochildren.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAPPLYTOCHILDREN() {
        return applytochildren;
    }

    /**
     * Définit la valeur de la propriété applytochildren.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAPPLYTOCHILDREN(String value) {
        this.applytochildren = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété categorycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCATEGORYCODE() {
        return categorycode;
    }

    /**
     * Définit la valeur de la propriété categorycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCATEGORYCODE(String value) {
        this.categorycode = value;
    }

    /**
     * Obtient la valeur de la propriété rstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Définit la valeur de la propriété rstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Obtient la valeur de la propriété rbsignaturetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRBSIGNATURETYPE() {
        return rbsignaturetype;
    }

    /**
     * Définit la valeur de la propriété rbsignaturetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRBSIGNATURETYPE(String value) {
        this.rbsignaturetype = value;
    }

    /**
     * Obtient la valeur de la propriété safetyReviewDetail.
     * 
     * @return
     *     possible object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public SafetyReviewDetail getSafetyReviewDetail() {
        return safetyReviewDetail;
    }

    /**
     * Définit la valeur de la propriété safetyReviewDetail.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public void setSafetyReviewDetail(SafetyReviewDetail value) {
        this.safetyReviewDetail = value;
    }

    /**
     * Obtient la valeur de la propriété has_Department_Security.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHas_Department_Security() {
        return has_Department_Security;
    }

    /**
     * Définit la valeur de la propriété has_Department_Security.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHas_Department_Security(String value) {
        this.has_Department_Security = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/entitysafetydefault_001/EntitySafetyDefault.java <==

package net.datastream.schemas.mp_entities.entitysafetydefault_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DELETEPENDING" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}APPLYTOCHILDREN" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CATEGORYCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RBSIGNATURETYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EntitySafetyDefault_001}SafetyReviewDetail" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="has_department_security" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "deletepending",
    "applytochildren",
    "locationid",
    "categorycode",
    "rstatus",
    "rbsignaturetype",
    "safetyReviewDetail"
})
@XmlRootElement(name = "EntitySafetyDefault")
public class EntitySafetyDefault {

    @XmlElement(name = "DELETEPENDING", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String deletepending;
    @XmlElement(name = "APPLYTOCHILDREN", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String applytochildren;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "CATEGORYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String categorycode;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlElement(name = "RBSIGNATURETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String rbsignaturetype;
    @XmlElement(name = "SafetyReviewDetail")
    protected SafetyReviewDetail safetyReviewDetail;
    @XmlAttribute(name = "has_department_security")
    protected String has_Department_Security;

    /**
     * Gets the value of the deletepending property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDELETEPENDING() {
        return deletepending;
    }

    /**
     * Sets the value of the deletepending property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDELETEPENDING(String value) {
        this.deletepending = value;
    }

    /**
     * Gets the value of the applytochildren property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAPPLYTOCHILDREN() {
        return applytochildren;
    }

    /**
     * Sets the value of the applytochildren property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAPPLYTOCHILDREN(String value) {
        this.applytochildren = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the categorycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCATEGORYCODE() {
        return categorycode;
    }

    /**
     * Sets the value of the categorycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCATEGORYCODE(String value) {
        this.categorycode = value;
    }

    /**
     * Gets the value of the rstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Sets the value of the rstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Gets the value of the rbsignaturetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRBSIGNATURETYPE() {
        return rbsignaturetype;
    }

    /**
     * Sets the value of the rbsignaturetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRBSIGNATURETYPE(String value) {
        this.rbsignaturetype = value;
    }

    /**
     * Gets the value of the safetyReviewDetail property.
     * 
     * @return
     *     possible object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public SafetyReviewDetail getSafetyReviewDetail() {
        return safetyReviewDetail;
    }

    /**
     * Sets the value of the safetyReviewDetail property.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public void setSafetyReviewDetail(SafetyReviewDetail value) {
        this.safetyReviewDetail = value;
    }

    /**
     * Gets the value of the has_Department_Security property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHas_Department_Security() {
        return has_Department_Security;
    }

    /**
     * Sets the value of the has_Department_Security property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHas_Department_Security(String value) {
        this.has_Department_Security = value;
    }

}
